@@ -2,7 +2,11 @@
 
 require_relative "../../spec_helper"
 
-if defined?(::Dalli)
+should_run =
+  defined?(::Dalli) &&
+  Gem::Version.new(::Dalli::VERSION) < Gem::Version.new("3")
+
+if should_run
   require_relative "../../support/cache_store_helper"
   require "active_support/cache/dalli_store"
   require "timecop"
