@@ -5,8 +5,7 @@ require "bundler/setup"
 require "minitest/autorun"
 require "minitest/pride"
 require "rack/test"
-require "rails"
-
+require "active_support"
 require "rack/attack"
 
 if RUBY_ENGINE == "ruby"
@@ -29,7 +28,9 @@ class MiniTest::Spec
   include Rack::Test::Methods
 
   before do
-    Rails.cache = nil
+    if Object.const_defined?(:Rails) && Rails.respond_to?(:cache)
+      Rails.cache.clear
+    end
   end
 
   after do
